#
# spec file for package nodejs-packaging
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _rpmconfigdir %{_prefix}/lib/rpm
Name:           nodejs-packaging
Version:        10.beta11
Release:        4.2
Summary:        Node.js Dependency generators for openSUSE
License:        MIT
Group:          Development/Languages/NodeJS
URL:            https://github.com/marguerite/nodejs-packaging
Source:         %{name}-%{version}.tar.gz
BuildArch:      noarch
Requires:       gcc-c++
Requires:       nodejs-devel
Requires:       npm
Requires:       ruby
Requires:       rubygem(json)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package generates Node.js Provides/Requires dependencies
automatically for nodejs module packages in openSUSE.

%package -n npkg
Summary:        The ultimate Node.js packaging toolkit for openSUSE
Group:          Development/Languages/NodeJS
Requires:       nodejs-packaging = %{version}
Requires:       ruby
Requires:       rubygem(json)
Requires:       rubygem(nokogiri)

%description -n npkg
This package provides the ultimate Node.js packaging toolkit
for openSUSE.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/npkg
mkdir -p %{buildroot}%{_rpmconfigdir}/{nodejs,fileattrs}
# 13.2's nodejs-devel package has a /etc/rpm/macros.nodejs
%if 0%{?suse_version} == 1320
mkdir -p %{buildroot}%{_sysconfdir}/rpm
install -m0644 macros.nodejs %{buildroot}%{_sysconfdir}/rpm/macros.%{name}
%else
mkdir -p %{buildroot}%{_rpmmacrodir}
install -m0644 macros.nodejs %{buildroot}%{_rpmmacrodir}/macros.nodejs
%endif
cp -r nodejs/* %{buildroot}%{_rpmconfigdir}/nodejs
cp -r tool/* %{buildroot}%{_datadir}/npkg
cp -r scripts %{buildroot}%{_datadir}/npkg
ln -sf %{_datadir}/npkg/npkg %{buildroot}%{_bindir}/npkg
ln -sf %{_datadir}/npkg/scripts/npkg-mgmt-pkg-batchrm.rb %{buildroot}%{_bindir}/npkg-mgmt-pkg-batchrm
ln -sf %{_datadir}/npkg/scripts/npkg-mgmt-json2pkgtxt.rb %{buildroot}%{_bindir}/npkg-mgmt-json2pkgtxt
ln -sf %{_datadir}/npkg/scripts/npkg-mgmt-merge.rb %{buildroot}%{_bindir}/npkg-mgmt-merge
install -m0644 nodejs.attr %{buildroot}%{_rpmconfigdir}/fileattrs/nodejs.attr
install -m0755 nodejs.prov %{buildroot}%{_rpmconfigdir}/nodejs.prov
install -m0755 nodejs.req %{buildroot}%{_rpmconfigdir}/nodejs.req
install -m0755 nodejs.rb %{buildroot}%{_rpmconfigdir}/nodejs.rb
install -m0755 nodejs-fixdep.rb %{buildroot}%{_rpmconfigdir}/nodejs-fixdep.rb
install -m0755 nodejs-check.rb %{buildroot}%{_rpmconfigdir}/nodejs-check.rb
install -m0755 nodejs-symlink-deps.rb %{buildroot}%{_rpmconfigdir}/nodejs-symlink-deps.rb

%files
%defattr(-,root,root)
%doc COPYING SHORTCOMINGS README.md
%if 0%{?suse_version} == 1320
%config %{_sysconfdir}/rpm/macros.%{name}
%else
%{_rpmmacrodir}/macros.nodejs
%endif
%if 0%{?suse_version} == 1110
%dir %{_rpmconfigdir}/fileattrs
%endif
%{_rpmconfigdir}/fileattrs/nodejs.attr
%{_rpmconfigdir}/nodejs.prov
%{_rpmconfigdir}/nodejs.req
%{_rpmconfigdir}/nodejs.rb
%{_rpmconfigdir}/nodejs-fixdep.rb
%{_rpmconfigdir}/nodejs-symlink-deps.rb
%{_rpmconfigdir}/nodejs-check.rb
%{_rpmconfigdir}/nodejs

%files -n npkg
%defattr(-,root,root)
%{_bindir}/npkg
%{_bindir}/npkg-mgmt-pkg-batchrm
%{_bindir}/npkg-mgmt-json2pkgtxt
%{_bindir}/npkg-mgmt-merge
%{_datadir}/npkg

%changelog
* Mon Nov 28 2022 Steve Kowalik <steven.kowalik@suse.com>
- Drop unneeded Requires on python.
* Wed Feb 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Files in /usr/lib/rpm/macros.d are not config files: drop %%config
  marker.
* Tue Feb 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Move rpm macro file from /etc/rpm to /usr/lib/rpm/macros.d
  (boo#1191387).
* Fri Jul  1 2016 toddrme2178@gmail.com
- Fix typo in Group tag.
* Thu Jun 16 2016 i@marguerite.su
- update version v10.beta11
  * bower.rb: github tags can be in more than one page. so
    the check for avaiable versions should be recursive.
* Tue Mar 29 2016 i@marguerite.su
- update version v10.beta10
  * sometimes bower.json doesn't have dependencies tag
  * fix encodings for nodejs-check.rb
  * add --drop option to nodejs-fixdep.rb to drop dependency
* Tue Mar  1 2016 i@marguerite.su
- update version v10.beta9
  * expose build log in nodejs_build macro
  * nodejs_build: more general build using node-gyp,
    depends on the existence of compiled .node files
  * filter 'sample' directory when copying files
  * auto link executables in bin to /usr/bin, you can
    delete unneeded ones later
  * add nodejs_check macro, easy to check for unsatisfied
    dependency now
  * bugfix: semver.rb can't handle version like '1.0.0-rc3'
  * bugfix: sometimes 'engines' tag is empty
  * bugfix: nodejs-fixdep can't handle multiple occurance
    of the same module
* Fri Feb 26 2016 i@marguerite.su
- update version v10.beta8
  * recursively copy files and fix exec permissions
    for all files outside bin (github#6)
  * colored text to prompt sources that should be
    deleted for npkg
  * bugfix: .css pattern will be skipped when copy
    because of the regex ".c"
  * bugfix: if two versions of tarball, only one
    version will be copied.
  * bugfix: bower in npkg, sometimes multiple name-*
    will be found
* Thu Feb 25 2016 i@marguerite.su
- update version v10.beta7
  * fix bugs related with licenses in dependency.rb
  * nodejs.rb: fix a bug that 'v2.0.0' dir will be renamed
  * fix a bug in semver.rb
  * add npkg-mgmt-merge: possible to create a huge bundle
  * add bower.rb plugin to handle bower dependencies
  * build C node modules automatically
  * add a global filter for rpmlint warnings
* Sun Feb 14 2016 i@marguerite.su
- update version v10.beta6
  * history.rb: some version exists in version timestamp
    but has no details, not downloadable, so drop them
  * clean_temp for parent.rb: don't use array substraction,
    it will all values matched. we just need to free the last
  * skiploop in dependencies.rb: parents variable can be
    nested arrays
  * skip in dependencies.rb: let those "parent" element
    without "name" variable return -1 to break infinite loop
  * vcmp.rb: fix a bug in ">=" test
* Fri Feb 12 2016 i@marguerite.su
- update version v10.beta5
  * rename nova to npkg, avoid conflict with openstack nova
  * style check w/ rubocop
  * initial SLE_11 support
  * rewrite vcmp to support beta versions
  * use vcmp and bundle sort for history.rb
* Wed Feb 10 2016 i@marguerite.su
- update version v10.beta4
  + optimization:
  * nova: delta download for .tgz files
  * dependencies.rb: delete tmp files at the last step for reuse
  * tweak the format of download .lst
  + bugfix:
  * don't add standard FHS directories into files.lst
  * should find the maximum node version, not the minimum
  * don't skip the loop if version is different with existing one
  * use vcmp in nodejs.rb
  * history.rb: the result for 'all' function is not natively sorted
  + feature:
  * support using bundle packages as dependencies
* Thu Feb  4 2016 i@marguerite.su
- update version v10.beta3
  * fix history.rb. take beta versions into consideration
  * use VCMP on history.rb; workaround for weird '1.0.2-1.2.3' version
  * fix github#4. the nopt issue is not isolated, use an universal solution
  * fix dependencies.rb: child can't have parent as dependency
  * dependencies.rb: don't loop the parent in child again and don't
    overwrite the module that already has dependencies
  * workaround for wrong '>= 4.0.0 < 5.0.0' range
  * add nodejs-symlink-deps macro back
  * add node-mgmt-batch-delete.rb and node-mgmt-json2pkgtxt.rb
    for users to migrate from old way to new packaging method
* Tue Feb  2 2016 i@marguerite.su
- update version v10.beta2
  * parent.rb: reimplemented json parent finding logic, works
    for complicated cases. tested on: gulp, read-pkg-up, read-pkg,
    which have multiple pinkie-promise on different tree branches.
  * re-add %%nodejs_fixdep macro: allow you to tweak module
    dependencies for modules in buildroot (please not run it
    at %%prep any more! run at %%install)
  * add specfile template for nodejs-packaging in tool directory
  * ensure File.open in UTF-8 mode, thanks to @illuusio
  * several rounds of bugfixes
* Sat Jan 30 2016 i@marguerite.su
- update version v10.beta
  * add nova tool and macros for automatic package processing
* Tue Jan 26 2016 i@marguerite.su
- update version 9
  * first public release
  * add nodejs(engine) Requires
  * provides the internal modules as own(xxx)
* Sat Jan 23 2016 i@marguerite.su
- update version 8
  * rewrite w/ ruby
  * support escaping the local modules in node_modules
    when finding Provides/Requires
- source changed to my reimplementation using ruby
  * https://github.com/marguerite/nodejs-packaging
- dropped: nodejs-packaging-compat-opensuse.patch
- dropped: nodejs-packaging-compat-opensuse-pre1320.patch
* Sat Nov 21 2015 lars@linux-schulserver.de
- build require xz for older build systems
* Wed Jul 29 2015 marec@detebe.org
- adding %%nodejs_install macro for version 1320+
* Sat Jul  4 2015 i@marguerite.su
- update version 7
- set fedora scm as its upstream url
- no conditional source
  * add patch: nodejs-packaging-compat-opensuse-pre1320.patch
  * add patch: nodejs-packaging-compat-opensuse.patch
  * drop patch: nodejs-packaging-pre1320-macros.patch
- rename the macros file only on specific version of openSUSE
* Wed Jan 28 2015 marec@detebe.org
- changed name of rpm macro file in order to prevent conflict with
  rpm macro from some versions of nodejs package with same filename
- added macro definitions from nodejs package to this rpm macro file
  because they are missing in some versions of nodejs package
- added patch: nodejs-packaging-pre1320-macros.patch
* Fri Oct 17 2014 dimstar@opensuse.org
- Don't use conditional Sources: we want to get uniform src.rpms
  that can be re-used. Do the condition in the %%prep section, where
  the specifically chosen tarball is extracted.
* Fri Oct 17 2014 jgleissner@suse.com
- require nodejs to make sure /usr/lib/node_modules is owned (may
  break build of module packages otherwise)
* Fri Oct 17 2014 jgleissner@suse.com
- removed use of %%nodejs_find_provides_and_requires macro (was
  added by accident)
* Thu Oct  9 2014 jgleissner@suse.com
- use nodejs-packaging for building
* Tue Oct  7 2014 jgleissner@suse.com
- added %%nodejs_modulesdir to macros.nodejs for older releases
* Tue Oct  7 2014 jgleissner@suse.com
- explicitely require Python
* Mon Oct  6 2014 jgleissner@suse.com
- initial check-in
